@@ -115,7 +115,10 @@ class SimpleTokenizer(object):
             bpe_tokens.extend(self.encoder[bpe_token] for bpe_token in self.bpe(token).split(' '))
         return bpe_tokens
 
-    def decode(self, tokens):
+    def decode(self, tokens, remove_start_end = True):
+        if remove_start_end:
+            tokens[tokens == 49407] = 0
+            tokens[tokens == 49406] = 0
         text = ''.join([self.decoder[token] for token in tokens])
         text = bytearray([self.byte_decoder[c] for c in text]).decode('utf-8', errors="replace").replace('</w>', ' ')
         return text
